dnl version $Id: ac_dmtoffline.m4 6520 2011-11-01 19:24:44Z john.zweizig@LIGO.ORG $
dnl -*- m4 -*-
dnl----------------------------------------------------------------------
dnl This is a common set of macros to be used in the configuration of
dnl	the low latency data service
dnl----------------------------------------------------------------------

dnl======================================================================
dnl L3D2_CHECK_GANGLIA
dnl   Check if GANGLIA is installed
dnl======================================================================

AC_DEFUN([AC_L3D2_CHECK_GANGLIA],
[
AC_MSG_CHECKING([whether ganglia plugin enabled])
gangliacflags=
AC_ARG_ENABLE([ganglia],
	      AC_HELP_STRING([--enable-ganglia],
			   [build a ganglia plugin]),
	      [], [enable_ganglia=no])
AC_MSG_RESULT([$enable_ganglia])
if test $enable_ganglia = "yes"
then
  if test ! -f /usr/include/gm_metric.h
  then
    AC_MSG_ERROR([cannot find ganglia module headers])
  fi
  PKG_CHECK_MODULES(APR, [apr-1], enable_ganglia="yes", enable_ganglia="no")
  if test "$enable_ganglia" = "no"
  then
    AC_MSG_ERROR([cannot find apr-1 package])
  fi
  gangliacflags=$APR_CFLAGS
fi
AM_CONDITIONAL([ganglia_plugin], test x$enable_ganglia != xno )
AC_SUBST([gangliacflags])
])

dnl======================================================================
dnl L3D2_CHECK_GDS
dnl   Check if GDS is installed
dnl======================================================================

AC_DEFUN([AC_L3D2_CHECK_GDS],
[
AC_MSG_CHECKING([for gds installation path])
AC_ARG_WITH(gds,
	    AC_HELP_STRING([--with-gds@<:@=PATH@:>@],
			   [path to the gds package @<:@/usr@:>@]))
gdsdir=$with_gds
gds_test=no
case x$with_gds in
x | xyes)
  gdsdir="/usr"
  gds_test=yes
  ;;
xno)
  ;;
*)
  gds_test=yes
  ;;
esac

gdsinclude=
gdslibdir=
if test $gds_test = yes
then
  gdsinclude="${gdsdir}/include/gds"
  if test ! -d ${gdsinclude}
  then
    gdsinclude="${gdsdir}/include"
  fi
  CFLAGS="${CFLAGS} -I${gdsinclude}"
  CXXFLAGS="${CXXFLAGS} -I${gdsinclude}"

  for ldir in lib lib64
  do
    if test -f $gdsdir/$ldir/libgdsbase.so
    then
      gdslibdir=$gdsdir/$ldir
    fi
  done
fi

AC_MSG_RESULT([$gds_test])

AC_MSG_CHECKING([gds directory])
AC_MSG_RESULT([$gdsdir])

if test x$gds_test = xno -a x$with_gds != xno
then
  AC_MSG_ERROR([can not find gds installation])
fi

AM_CONDITIONAL([have_gds], test x${gds_test} != xno )
AC_SUBST([gdsdir])
AC_SUBST([gdslibdir])

AC_PATH_PROG(DPUSH, DpushM)
AC_PATH_PROG(FRAMELINK, framelink)
AC_PATH_PROG(LSMPXMIT, lsmp_xmit)
AC_PATH_PROG(FRLOG, Frame_Log)
AC_PATH_PROG(SMCRE, smcreate)
AC_PATH_PROG(SMKILL, smkill)
AC_PATH_PROG(SMREP, smrepair)
AC_PATH_PROG(SMSTAT, smstat)
])

dnl======================================================================
dnl L3D2_CHECK_VIGO
dnl   Check if VIRGO is installed
dnl======================================================================

AC_DEFUN([AC_L3D2_CHECK_VIRGO_APP_FD],
[
AC_MSG_CHECKING([whether Virgo Fd applications requested])
AC_ARG_WITH([virgoapps],
	    AC_HELP_STRING([--with-virgoapps@<:@=PATH@:>@],
			   [path the the virgoApp-Fd package @<:@/usr@:>@. If
			   --without or no is specified, the FdtoDMT and 
			   DMTtoFd executables are not built]))

virgoapps=yes
virgo_cflags=""
virgo_libs=""
tmp_libbase=`echo ${libdir} | sed -e 's/^.*lib/lib/g'`
case "x$with_virgoapps" in
x|xyes)
  PKG_CHECK_MODULES([VIRGOFD], [virgoFd], [virgoapps=yes], [virgoapps=no])
  if test "$virgoapps" = "yes"
  then
    virgo_cflags="$VIRGOFD_CFLAGS"
    virgo_libs="$VIRGOFD_LIBS -lCm -lCSet -lReg -lFrame"
  elif test -f "/usr/include/Fd.h"
  then
    virgo_cflags="-I/usr/include/virgoApp"
    virgo_libs="-L/usr/${tmp_libbase} -lFd -lCm -lCSet -lReg -lFrame"
    virgoapps=no
  else
    virgoapps=no
  fi
  ;;
xno)
  virgoapps=no
  ;;
*)
  fdincdir=`ls -1d ${with_virgoapps}/include ${with_virgoapps}/include/virgoApp 2>/dev/null | tail -1`
  fdlibdir=`ls -1d ${with_virgoapps}/lib ${with_virgoapps}/lib64 2>/dev/null | tail -1`
  if test -d "${fdincdir}"
  then
    virgo_cflags="-I${fdincdir}"
    virgo_libs="-L${fdlibdir} -lFd -lCm -lCSet -lReg -lFrame"
  fi
  virgoapps=${with_virgoapps}
  ;;
esac

AC_MSG_RESULT([$virgoapps])
AM_CONDITIONAL([have_virgo], test x$virgoapps != xno )
AC_SUBST([virgo_cflags])
AC_SUBST([virgo_libs])
])

dnl======================================================================
dnl L3D2_CHECK_USER
dnl   Check if Username specified is installed
dnl======================================================================

AC_DEFUN([AC_L3D2_CHECK_USER],
[
have_user=no
lluser="lluser"
AC_ARG_WITH(user,
	    AC_HELP_STRING([--with-user@<:@=USER@:>@],
			   [server user name @<:@${lluser}@:>@]),
	    [have_user=yes],
	    [have_user=no]
	    )
if test x$have_user = xyes -a ! -z "$with_user"
then
   lluser=$with_user
fi

AC_SUBST(lluser)
])
